
*===============================================================================
*===============================================================================
* Transforming EU-SILC Data to have 1 data-set per country with all modules appended (2021-2022)
*===============================================================================
*===============================================================================

*--------------------------------------------------------
* 1) Import from .csv and save data as .dta
*--------------------------------------------------------

*Define the countries of interest: EU-27 (excluding Germany)
foreach cnt in BE BG CZ DK EE IE EL ES FR HR IT CY LV LT LU HU MT NL AT PL PT RO SI SK FI SE { 

*Define the years of interest
forval y=21/22{
	
*Define the modules needed
foreach mod in H P R D {
clear 

*First, import the dataset .csv to .dta format
clear
cap import delimited "$rawcross/`cnt'/20`y'/UDB_c`cnt'`y'`mod'.csv", case(upper) asdouble stringcols(2 4)

if _rc==601 noisily di "UDB_c`cnt'`y'`mod'.csv not found"

if ("`mod'"=="H" |  "`mod'"=="D") & _rc!=601 save "$createddata/UDB_c`cnt'`y'`mod'.dta", replace
if ("`mod'"=="P" | "`mod'"=="R") & _rc!=601 save "$createddata/UDB_c`cnt'`y'`mod'.dta", replace
}
}
}

*--------------------------------------------------------
* 2) Merge the cross-sectional modules 
*--------------------------------------------------------
foreach cnt in BE BG CZ DK DE EE IE EL ES FR HR IT CY LV LT LU HU MT NL AT PL PT RO SI SK FI SE { //EU-27

*Define the years of interest
forval y=21/22{

	clear 
cap u "$createddata/UDB_c`cnt'`y'P.dta"

if _rc!=601 {
clonevar RB030=PB030 //the household plus person id for the merge with personal registers

*Merge with the personal register file
qui merge 1:1 RB030 using "$createddata/UDB_c`cnt'`y'R.dta", nogen
clonevar HB030=RX030 //the househol id for the merge with household data

*tostring PB030, replace
*gen person_id=substr(PB030,-2,2)

*Merge with the household data
qui merge m:1 HB030 using "$createddata/UDB_c`cnt'`y'H.dta", nogen
clonevar DB030=HB030

*Now for the household register file
qui merge m:1 DB030 using "$createddata/UDB_c`cnt'`y'D.dta", nogen

*Basic cleaning of the data
rename *, lower
rename rb010 year		// db010
rename rb020 code
rename hb030 hhid
destring *, replace

*Save the dataset
save "$createddata/SILC_`cnt'`y'.dta", replace
}
}
}

*--------------------------------------------------------
* 3) Append 2021 and 2022 for each country   			 
*--------------------------------------------------------

foreach cnt in BE BG CZ DK DE EE IE EL ES FR HR IT CY LV LT LU HU MT NL AT PL PT RO SI SK FI SE { //EU-27
 clear
 cap u "$createddata/SILC_`cnt'21.dta"
 
 if _rc!=601 {
 cap append using "$createddata/SILC_`cnt'22.dta", force 	

*Save the dataset
save "$createddata/SILC_`cnt'_21-22.dta", replace

}
}



