
*===============================================================================
*===============================================================================
* Computation of anchored AROPE (anchored to 2019 survey year)
*===============================================================================
*===============================================================================

*----------------------------------------------------
* 1) anchored AROPE per country and year
*----------------------------------------------------

foreach cnt in  BE BG CZ DK DE EE IE EL ES FR HR IT CY LV LT LU HU MT NL AT PL PT RO SI SK FI SE {  //EU-27

	clear
	cap u "$createddata/SILC_`cnt'_21-22.dta"

	if _rc!=601 {
	
	noisily disp "`cnt'"	
	
	// weights
	qui gen wgt_ind = rb050 
	drop if wgt_ind==.
	
	qui gen wgt_hh = db090										  
	
	// id
	gen pid = pb030 											
	order code year hhid pid
	sort hhid pid

	// adding poverty line
	qui merge m:1 code using "$dofiles\externaldata-anchored_povline.dta"
	drop _merge
	
	// adding ipc and the HICP from Eurostat for comparability
	replace year=year-1
	qui merge m:1 code year using "$dofiles\externaldata-HICP_Eurostat.dta" 
	qui drop _merge
	
	// adjusted equivalent income variable in 2017 PPP (in local currency)
	qui gen double usd_ppp_adeq = (hx090*hx010)/(hicp_ann_2018) 

	// anchored AROP 																												
	qui gen anc_arop = .
	qui replace anc_arop = 1 if usd_ppp_adeq < anchor_adeq_2019
	qui replace anc_arop = 0 if usd_ppp_adeq >= anchor_adeq_2019
	
	/*
	note: for the rest of the loop: year = year-1
	*/
	
	noisily disp "`cnt'" 2021
	tab anc_arop if year==2020 [aw=wgt_ind]
	noisily disp "`cnt'" 2022
	tab anc_arop if year==2021 [aw=wgt_ind]
	
	// anchored AROPE
    drop if rx070==.

	gen anc_arope = 0
	replace anc_arope = 100 if anc_arop==1 | rx060==1 | rx050==1
	
	// show the country
	noisily disp "`cnt'"	
	
	*******************
	*** TABLE A3.2 ***
    *******************
	
	// arope STATS and create the excel file to store AROPE (0; 1)
	putexcel set "$tables\TableA3-2.xlsx", modify sheet(`cnt', replace) 
	
	putexcel A2 = "`cnt'"
	putexcel B1 = "Anchored AROPE-2021"
	putexcel C1 = "Anchored AROPE-2022"
	
	// 2021
	tabstat anc_arope [aw=wgt_ind] if year==2020, stat(mean) save 
	putexcel B2 = matrix(r(StatTotal))
	// 2022
	tabstat anc_arope [aw=wgt_ind] if year==2021, stat(mean) save 
	putexcel C2 = matrix(r(StatTotal))
	
}
}


*----------------------------------------------------
* 2) anchored AROPE: stats and figures
*----------------------------------------------------

use "$dofiles/externaldata-anch-arope-pop.dta", clear

*****************
*** FIGURE 2 ***
*****************
scatter arope_22 arope_21, mlabel(code) leg(off) || line arope_21 arope_21, sort ///
ytitle("AROPE 2022 (%)", size(small))  ///
xtitle("AROPE 2021 (%)", size(small))  ///
graphregion(color(white)) bgcolor(white) ylabel(,nogrid) 
graph export "$figures\Fig2.png", replace 

********************
*** TABLE  A3.1 ***
********************

gen anchored_arope_2021 = arope_21 * popw_2021
gen anchored_arope_2022 = arope_22 * popw_2022
replace anchored_arope_2021 = arope_21 if code=="EU-27"
replace anchored_arope_2022 = arope_22 if code=="EU-27"

gen change = anchored_arope_2022 - anchored_arope_2021
replace change = arope_22 - arope_21 if code=="EU-27"

gen subregions = .
replace subregions = 1 if code=="DK" | code=="EE" |code=="FI" |code=="LV" |code=="LT" | code=="SE"
replace subregions = 2 if code=="CY" | code=="EL" |code=="IT" |code=="MT" |code=="PT" |code=="ES"
replace subregions = 3 if code=="AT" | code=="BE" |code=="FR" |code=="IE" |code=="LU" |code=="NL"
replace subregions = 4 if code=="BG" |  code=="HR" | code=="CZ" | code=="HU" |code=="PL" |code=="RO" |code=="SK" |code=="SI"
replace subregions = 5 if code=="EU-27"

label define subregions 1 "Northern Europe (NE)" 2"Southern Europe (SE)" 3"Western Europe (WE) " 4"Central Eastern Europe (CEE) " 5 "EU-27 (excluding Germany)" 
label values subregions subregions

preserve 
collapse (sum) anchored_arope_2021 anchored_arope_2022 change, by(subregions)
export excel using "$tables\TableA3-1.xlsx", firstrow(variables) replace
restore


*****************
*** FIGURE 1 ***
*****************
import excel "$tables\TableA3-1.xlsx", sheet("Sheet1") firstrow clear

label var anchored_arope_2022 "AROPE 2022"

graph bar (asis) anchored_arope_2022, over(subregions, lab(angle(90))) ///
ytitle("Percentage of AROPE individuals (%)", size(small)) ///
graphregion(color(white)) bgcolor(white) ///
legend(size(small)) 
graph export "$figures\Fig1.png", replace 



