
*===============================================================================
*===============================================================================
* AROPE  --> Deprivations and profile: 4 EU countries of interest (BG-HR-RO-PL)
*===============================================================================
*===============================================================================

*--------------------------------------------------------
* 1) Data-set (BG-HR-PL-RO, 20-22)
*--------------------------------------------------------

// append data-sets to have 1 data with 4 countries (2021-2022)
use "$createddata/SILC_BG_21-22.dta", clear
qui append using "$createddata/SILC_HR_21-22.dta"
qui append using "$createddata/SILC_PL_21-22.dta"
qui append using "$createddata/SILC_RO_21-22.dta"

// country variable
clonevar country = code 
tab country year

// weights
gen wgt_ind = rb050
count if wgt_ind==.

qui gen wgt_hh = db090										  
count if wgt_ind==.

// rounding weight (for regression analysis)
gen weight_ind = round(wgt_ind)
	
// personal id
clonevar pid = pb030 
format pid  %9.0f

// hh id (by country and year)
sort code year hhid pid
egen hhid_cy = group(code year hhid) 
order code year hhid pid hhid_cy 

// AROPE (0; 1)
drop if rx070==.													

gen arope = 0
replace arope = 1 if rx070!=0
label var arope "At risk of poverty or social exclusion"

// AROP
clonevar arop = hx080

// LWI
clonevar lwi = rx050
recode lwi (2=.)

// materially deprived
clonevar deprived = rx060


*--------------------------------------------------------
* 2) Analyzing deprivations of AROPE
*--------------------------------------------------------

// Deprived in only 1 dimension
gen dim1_lwi = 0
replace dim1_lwi= 100 if rx070==1
gen dim1_md = 0
replace dim1_md= 100 if rx070==10
gen dim1_arop = 0
replace dim1_arop= 100 if rx070==100
// Deprived in only 2 dimensions
gen dim2_md_lwi = 0
replace dim2_md_lwi= 100 if rx070==11
gen dim2_arp_lwi = 0
replace dim2_arp_lwi= 100 if rx070==101
gen dim2_arp_md = 0
replace dim2_arp_md= 100 if rx070==110
// Deprived in 3 dimensions
gen dim3_all3 = 0
replace dim3_all3= 100 if rx070==111

// AROPE (100, 0)
gen arope_nat = 0
replace arope_nat = 100 if arope==1

****************
*** TABLE 3 ***
****************

putexcel set "$tables\Table3", replace
putexcel A1 = "AROPE"
putexcel A2 = "Deprived in only 1 dimension"
putexcel A3 = "low work intensity"
putexcel A4 = "severe material and social deprivation"
putexcel A5 = "at risk of poverty"
putexcel A6 = "Deprived in only 2 dimensions"
putexcel A7 = "several material and social deprivation + low work intensity"
putexcel A8 = "at risk of poverty + low work intensity"
putexcel A9 = "at risk of poverty + several material and social deprivation"
putexcel A10 = "Deprived in 3 dimensions"
putexcel A11 = "at risk of poverty + low work intensity + several material and social deprivation"
putexcel A12 = "national AROPE rate"
putexcel B1 = "Bulgaria"
putexcel C1 = "Croatia"
putexcel D1 = "Poland"
putexcel E1 = "Romania"

// Bulgaria
tabstat dim1_lwi if country=="BG" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel B3 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim1_md if country=="BG" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel B4 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim1_arop if country=="BG" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel B5 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_md_lwi if country=="BG" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel B7 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_arp_lwi if country=="BG" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel B8 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_arp_md if country=="BG" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel B9 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim3_all3 if country=="BG" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel B11 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="BG" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel B12 = matrix(r(StatTotal)), nformat(#.0)

// Croatia
tabstat dim1_lwi if country=="HR" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel C3 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim1_md if country=="HR" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel C4 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim1_arop if country=="HR" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel C5 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_md_lwi if country=="HR" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel C7 = matrix(r(StatTotal)), nformat(number_d2)
tabstat dim2_arp_lwi if country=="HR" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel C8 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_arp_md if country=="HR" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel C9 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim3_all3 if country=="HR" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel C11 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="HR" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel C12 = matrix(r(StatTotal)), nformat(#.0)

// Poland
tabstat dim1_lwi if country=="PL" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel D3 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim1_md if country=="PL" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel D4 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim1_arop if country=="PL" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel D5 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_md_lwi if country=="PL" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel D7 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_arp_lwi if country=="PL" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel D8 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_arp_md if country=="PL" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel D9 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim3_all3 if country=="PL" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel D11 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="PL" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel D12 = matrix(r(StatTotal)), nformat(#.0)

// Romania
tabstat dim1_lwi if country=="RO" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel E3 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim1_md if country=="RO" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel E4 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim1_arop if country=="RO" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel E5 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_md_lwi if country=="RO" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel E7 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_arp_lwi if country=="RO" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel E8 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_arp_md if country=="RO" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel E9 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim3_all3 if country=="RO" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel E11 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="RO" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel E12 = matrix(r(StatTotal)), nformat(#.0)


*--------------------------------------------------------
* 3) Creating vars for regression analysis
*--------------------------------------------------------

// hh tag
egen hh_level = tag(hhid_cy)

// age (at the end of the income reference period)
gen age=rx020 
replace age=rx010 if age==.    						// rx010: age at the date of the interview
count if age==.

// hh head 
gen hhead = 0
replace hhead = 1 if pid==hb070					// HB070: Person responding the hh questionnaire --> proxy of hh head

* in case there is no information available,  assign hh head to the first observation
bys hhid_cy: egen aux1 = sum(hhead)
gen flag1 = 1 if aux1==0
tab flag1 if hh_level==1									

bys hhid_cy: g i=_n
replace hhead = 1 if i==1 & flag1==1				
replace hhead = 1 if i==1 & hb070==.
replace hhead = 0 if age<10
drop i flag1

// age hh head
gen hhead_age_aux = age if hhead==1
bys hhid_cy: egen hhead_age=max(hhead_age_aux)
drop hhead_age_aux

// gender: rb090
count if rb090==.
clonevar male = rb090
recode male (2 = 0)

// location 
* rural
recode db100 (1 2=1) (3=0), gen(urban)
label var urban "Urban"	

 * degree of urbanization: densely-populated area, intermediate area, thinly-populated area 
gen densely = db100==1 if ~missing(db100)       // cities
gen inter = db100==2 if ~missing(db100)		     // towns and suburbs
gen thinly = db100==3 if ~missing(db100)		    // rural areas
 
// regions
foreach cnt in BG HR PL RO {
		tab db040 if country=="`cnt'", gen(reg_`cnt')
}

// hh size
count if hx040==.
clonevar hhsize=hx040

// number and share of adults aged 18-64 (hh-level)
gen adult_18_64 = age>17 & age<65 & age<.
bys hhid_cy: egen n_adult_18_64 = total(adult_18_64)
gen double sh_adult_18_64=n_adult_18_64/hhsize
drop adult_18_64

// number and share of children
gen children_0_18 = age<18 & age<.
bys hhid_cy: egen n_children_0_18 = total(children_0_18)
gen double sh_children_0_18=n_children_0_18/hhsize
drop children_0_18

// number and share of elderly
gen adults_65 = age>64 & age<.
bys hhid_cy: egen n_adults_65 = total(adults_65)
gen double sh_adults_65=n_adults_65/hhsize
drop adults_65

// household type: child, adult, old
gen adult=age>15 & age<.
gen child=(age<=15 & age!=.)
gen old=(age>64 & age!=.)
gen workage=(age>15 & age<=64)
bys hhid_cy: egen n_child=total(child)
bys hhid_cy: egen n_old = total(old)
bys hhid_cy: egen n_adult = total(adult)
	
gen double sh_childold=(n_child+n_old)/hx040
gen double sh_child=n_child/hx040
gen double sh_old=n_old/hx040

foreach i of varlist sh_* {
	recode `i' (.=0)
}

// vulnerable hhs

* female headed
gen femalehead = (male==0 & hhead==1)
bys hhid_cy: egen femaleheaded_hh=max(femalehead)

* hh with at least one unemployed
gen unemployed = 1 if pl032==2 & year>=2021
bys hhid_cy: egen unemployed_hh=max(unemployed)
replace unemployed_hh = 0 if unemployed_hh==.

* single elderly household
gen elderly=(age>64)
gen single_elderly=0
replace single_elderly=1 if elderly==1 & hhsize==1
gen single_elderly_hh = single_elderly

* hh with 3 or more children
gen hh_3more_children=0
replace hh_3more_children=1 if n_children_0_18>=3

* hh with children < 6 years old
gen child_06=(age<6)
bys hhid_cy: egen hh_child_06=max(child_06)

* hh with 5 or more members
gen hh_5members = 0
replace hh_5members=1 if hhsize>4 

* hh with disabled
gen disabled = (py130g>0)
bys hhid_cy: egen disabled_hh=max(disabled)

* hh with pensioner
gen pensioner = (py100g>0)
replace pensioner = 0 if missing(py100g)
cap drop pensioner_hh
bys hhid_cy: egen pensioner_hh=max(pensioner)

* hh with social aid (HY060N - Social exclusion not elsewhere classified)
gen socialaid = 0
replace socialaid=1 if hy060n>0 & hy060n!=.
tab socialaid 
bys hhid_cy: egen socialaid_hh=max(socialaid)

// tenure status of the hh head
recode hh021 (1 2=1) (3 4 5=0), gen(owner)
label var owner "house owner"	

gen owner_hhead_aux = owner if hhead==1
bys hhid_cy: egen owner_hhead=max(owner_hhead_aux)
drop owner_hhead_aux

// education level (pe040: highest ISCED level attained)
gen edu=.
replace edu= 1 if pe041==0 & year>=2021  											//Less primary
replace edu= 1 if inrange(pe041,100,200) & year>=2021 					//Completed primary
replace edu= 2 if inrange(pe041,340,490) & year>=2021 					//Completed secondary
replace edu= 3 if inrange(pe041,500,800) & year>=2021 					//Tertiary

label def edu  1"primary educ" 2"secondary educ" 3"tertiary educ"
label values edu edu

// education level of the hh head
gen edu_hhead_aux = edu if hhead==1
bys hhid_cy: egen edu_hhead=max(edu_hhead_aux)
bys hhid_cy: egen edu_hhead2=max(edu)
drop edu_hhead_aux

/* flag: there are many missings in the original variable */
* in PL:  259 hhs with missing info on education --> in those cases, I assign the level of educ of the other adult member (not to lose obs.)
replace edu_hhead=edu_hhead2 if edu_hhead==.
drop edu_hhead2

label def edu_hhead  1"primary educ" 2"secondary educ" 3"tertiary educ"
label values edu_hhead edu_hhead

// labor force status
gen lfstat1=. 
ta pl032,m 
			 replace lfstat1=1 if (pl032==1) & year>=2009 & year>=2021 // employee working full-time, employee working part-time, self-employed full time, self-employed part time
             replace lfstat1=2 if pl032==2 & year>=2009 & year>=2021 // unemployed
             replace lfstat1=3 if pl032==3 & year>=2009 & year>=2021 // retired
             replace lfstat1=4 if (pl032==4|pl032==6|pl032==7|pl032==8) & year>=2009 & year>=2021 // long-term disability, military/community or service, care responsibilities, other inactive person
             replace lfstat1=5 if pl032 ==5  & year>=2009 & year>=2021 // student

				replace lfstat1=. if age<=15
				recode lfstat1 (1=1)(2=2)(3=3)(4=4)(5=5)(.=.), gen(lfstat)
				label define lfstat 1 "Employed" 2"Unemployed" 3"Retired" 4"Inactive" 5"Student"
                label values lfstat lfstat

// labor force status of the hh head
gen lfstat_hhead_aux = lfstat if hhead==1
bys hhid_cy: egen lfstat_hhead=max(lfstat_hhead_aux)
drop lfstat_hhead_aux

label define lfstat_hhead 1 "Employed" 2"Unemployed" 3"Retired" 4"Inactive" 5"Student"
label values lfstat_hhead lfstat_hhead


*--------------------------------------------------------
* 4) Creating vars for AROPE +
*--------------------------------------------------------

// at least 1 adult in the hh with less than secondary educ. (hh-level)
gen deprived_educ_aux = 1 if edu==1 & age>=18
bys hhid_cy: egen deprived_educ_hh=min(deprived_educ_aux)
replace deprived_educ_hh=0 if deprived_educ_hh==.
label var deprived_educ_hh "at least 1 adult in the hh with less than sec. educ."
drop deprived_educ_aux

// education (hh head)
gen deprived_educ_hhead = .
replace deprived_educ_hhead = 1 if edu_hhead==1									// less than secondary
replace deprived_educ_hhead = 0 if edu_hhead!=1

// at least 1 adult with unmet need for medical examination or treatment 
gen unmet_med = .
replace unmet_med = 1 if ph040==1
replace unmet_med = 0 if ph040==2

gen unmet_med_aux2 = unmet_med
bys hhid_cy: egen unmet_med_hh=max(unmet_med_aux2)
label var unmet_med_hh " at least 1 adult with unmet medical needs"
drop unmet_med unmet_med_aux2

// crowding index (average number of people per room available to the household) > 2 (HH030) 
gen pers_room = hhsize/hh030
gen crowding = .
replace crowding = 1 if pers_room>2
replace crowding = 0 if pers_room<=2


// label vars
label var male "male"
label var age "age"
label var owner_hhead "home ownership"
label var  unmet_med_hh "unmet medical needs"
label var  crowding "overcrowded house"
label var  n_children_0_18 "number of individuals <18"
label var  n_adult_18_64 "number of individuals 18-64"
label var  n_adults_65 "number of individuals >64"
label  var femaleheaded_hh "female headed hh"
label var  unemployed_hh "hh with unemployed"
label var  single_elderly_hh "single-elderly hh"
label var  hh_3more_children "hh with 3 or more children"
label var   hh_5members "hh with 5 or more members"
label var  disabled_hh "hh with disability recipient"
label var  pensioner_hh "hh with pensioner"
label var  socialaid_hh "hh with social aid"
label var  inter "towns and suburbs"
label var  thinly " rural areas"
label var  densely "cities"

// create categories for education and lfstat
gen edu_hhead_1 = 1 if edu_hhead==1
replace edu_hhead_1=0 if edu_hhead!=1
gen edu_hhead_2 = 1 if edu_hhead==2
replace edu_hhead_2=0 if edu_hhead!=2
gen edu_hhead_3 = 1 if edu_hhead==3
replace edu_hhead_3=0 if edu_hhead!=3
label var edu_hhead_1 "primary educ"
label var edu_hhead_2 "secondary educ"
label var edu_hhead_3 "tertiary educ"

gen lfstat_hhead_1 = 1 if lfstat_hhead==1
replace lfstat_hhead_1=0 if lfstat_hhead!=1
gen lfstat_hhead_2 = 1 if lfstat_hhead==2
replace lfstat_hhead_2=0 if lfstat_hhead!=2
gen lfstat_hhead_3 = 1 if lfstat_hhead==3
replace lfstat_hhead_3=0 if lfstat_hhead!=3
gen lfstat_hhead_4 = 1 if lfstat_hhead==4
replace lfstat_hhead_4=0 if lfstat_hhead!=4
gen lfstat_hhead_5 = 1 if lfstat_hhead==5
replace lfstat_hhead_5=0 if lfstat_hhead!=5
label var lfstat_hhead_1 "Employed"
label var lfstat_hhead_2 "Unemployed"
label var lfstat_hhead_3 "Retired"
label var lfstat_hhead_4 "Inactive"
label var lfstat_hhead_5 "Student"

*******************************************
*******************************************
* Saving intermediate data-set:
save "$createddata/SILC_BG-HR-PL-RO_21-22", replace
*******************************************
use "$createddata/SILC_BG-HR-PL-RO_21-22", clear
*******************************************
*******************************************

*--------------------------------------------------------
* 5) Unconditional AROPE profile 												
*--------------------------------------------------------

****************
*** TABLE 4 ***
****************

putexcel set "$tables\Table4", replace
putexcel A1 = "vulnerable households"
putexcel A2 = "household with unemployed"
putexcel A3 = "single-elderly household"
putexcel A4 = "female-headed household"
putexcel A5 = "household with 3 or more children"
putexcel A6 = "household with 5 or more members"
putexcel A7 = "household with disability recipient"
putexcel A8 = "household with pensioner"
putexcel A9 = "household with social aid"
putexcel A10 = "national AROPE rate"
putexcel B1 = "Bulgaria"
putexcel C1 = "Croatia"
putexcel D1 = "Poland"
putexcel E1 = "Romania"

// Bulgaria
tabstat arope_nat if country=="BG" & year==2022 & unemployed_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel B2 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="BG" & year==2022 & single_elderly_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel B3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="BG" & year==2022 & femaleheaded_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel B4 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="BG" & year==2022 & hh_3more_children==1 [aw=wgt_ind] , stat(mean) save 
putexcel B5 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="BG" & year==2022 & hh_5members==1 [aw=wgt_ind] , stat(mean) save 
putexcel B6 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="BG" & year==2022 & disabled_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel B7 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="BG" & year==2022 & pensioner_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel B8 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="BG" & year==2022 & socialaid_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel B9 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="BG" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel B10 = matrix(r(StatTotal)), nformat(#.0)

// Croatia
tabstat arope_nat if country=="HR" & year==2022 & unemployed_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel C2 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="HR" & year==2022 & single_elderly_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel C3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="HR" & year==2022 & femaleheaded_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel C4 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="HR" & year==2022 & hh_3more_children==1 [aw=wgt_ind] , stat(mean) save 
putexcel C5 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="HR" & year==2022 & hh_5members==1 [aw=wgt_ind] , stat(mean) save 
putexcel C6 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="HR" & year==2022 & disabled_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel C7 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="HR" & year==2022 & pensioner_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel C8 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="HR" & year==2022 & socialaid_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel C9 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="HR" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel C10 = matrix(r(StatTotal)), nformat(#.0)
 
 // Poland
tabstat arope_nat if country=="PL" & year==2022 & unemployed_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel D2 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="PL" & year==2022 & single_elderly_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel D3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="PL" & year==2022 & femaleheaded_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel D4 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="PL" & year==2022 & hh_3more_children==1 [aw=wgt_ind] , stat(mean) save 
putexcel D5 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="PL" & year==2022 & hh_5members==1 [aw=wgt_ind] , stat(mean) save 
putexcel D6 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="PL" & year==2022 & disabled_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel D7 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="PL" & year==2022 & pensioner_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel D8 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="PL" & year==2022 & socialaid_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel D9 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="PL" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel D10 = matrix(r(StatTotal)), nformat(#.0)
 
  // Romania
tabstat arope_nat if country=="RO" & year==2022 & unemployed_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel E2 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="RO" & year==2022 & single_elderly_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel E3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="RO" & year==2022 & femaleheaded_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel E4 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="RO" & year==2022 & hh_3more_children==1 [aw=wgt_ind] , stat(mean) save 
putexcel E5 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="RO" & year==2022 & hh_5members==1 [aw=wgt_ind] , stat(mean) save 
putexcel E6 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="RO" & year==2022 & disabled_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel E7 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="RO" & year==2022 & pensioner_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel E8 = matrix(r(StatTotal)), nformat(#.0)
putexcel E9 = "-"
tabstat arope_nat if country=="RO" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel E10 = matrix(r(StatTotal)), nformat(#.0)


****************
*** TABLE 5 ***
****************

putexcel set "$tables\Table5", replace
putexcel A1 = "other deprivations"
putexcel A2 = "education: household head with only primary education"
putexcel A3 = "health: at least one adult with unmet medical needs"
putexcel A4 = "housing: overcrowded house"
putexcel A5 = "national AROPE rate"
putexcel B1 = "Bulgaria"
putexcel C1 = "Croatia"
putexcel D1 = "Poland"
putexcel E1 = "Romania"

// Bulgaria
tabstat arope_nat if country=="BG" & year==2022 & deprived_educ_hhead==1 [aw=wgt_ind] , stat(mean) save 
putexcel B2 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="BG" & year==2022 & unmet_med_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel B3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="BG" & year==2022 & crowding==1 [aw=wgt_ind] , stat(mean) save 
putexcel B4 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="BG" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel B5 = matrix(r(StatTotal)), nformat(#.0)

// Croatia
tabstat arope_nat if country=="HR" & year==2022 & deprived_educ_hhead==1 [aw=wgt_ind] , stat(mean) save 
putexcel C2 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="HR" & year==2022 & unmet_med_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel C3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="HR" & year==2022 & crowding==1 [aw=wgt_ind] , stat(mean) save 
putexcel C4 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="HR" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel C5 = matrix(r(StatTotal)), nformat(#.0)

// Poland
tabstat arope_nat if country=="PL" & year==2022 & deprived_educ_hhead==1 [aw=wgt_ind] , stat(mean) save 
putexcel D2 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="PL" & year==2022 & unmet_med_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel D3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="PL" & year==2022 & crowding==1 [aw=wgt_ind] , stat(mean) save 
putexcel D4 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="PL" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel D5 = matrix(r(StatTotal)), nformat(#.0)

// Romania
tabstat arope_nat if country=="RO" & year==2022 & deprived_educ_hhead==1 [aw=wgt_ind] , stat(mean) save 
putexcel E2 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="RO" & year==2022 & unmet_med_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel E3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="RO" & year==2022 & crowding==1 [aw=wgt_ind] , stat(mean) save 
putexcel E4 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if country=="RO" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel E5 = matrix(r(StatTotal)), nformat(#.0)


****************
*** TABLE 6 ***
****************

version 15

// to report 1st column AROPE
gen arope_aux = 1 if arope==1
replace arope_aux=2 if arope==0

label define arope_aux 1 "AROPE" 2"non-AROPE" 
label values arope_aux arope_aux

// variables of interest
global vars age male ///
					owner_hhead edu_hhead_1 edu_hhead_2 edu_hhead_3 lfstat_hhead_1 lfstat_hhead_2 lfstat_hhead_3 lfstat_hhead_4 lfstat_hhead_5 ///
					unmet_med_hh crowding ///
					n_children_0_18 n_adult_18_64 n_adults_65 ///
					femaleheaded_hh unemployed_hh single_elderly_hh hh_3more_children hh_5members disabled_hh pensioner_hh socialaid_hh ///
					densely inter thinly

*** MEANS			
// Bulgaria
estpost tabstat $vars [aw=wgt_ind] if country=="BG" & year==2022, by(arope_aux) statistics(mean) columns(statistics) nototal
esttab . using "$tables\Table6-BG.xls", main(mean) nostar unstack noobs nonote label  cells("mean(fmt(a2))") replace

 // Croatia
estpost tabstat $vars [aw=wgt_ind] if country=="HR" & year==2022, by(arope_aux) statistics(mean) columns(statistics) nototal
esttab . using "$tables\Table6-HR.xls", main(mean) nostar unstack noobs nonote label  cells("mean(fmt(a2))") replace

 // Poland
estpost tabstat $vars [aw=wgt_ind] if country=="PL" & year==2022, by(arope_aux) statistics(mean) columns(statistics) nototal
esttab . using "$tables\Table6-PL.xls", main(mean) nostar unstack noobs nonote label  cells("mean(fmt(a2))") replace

 // Romania
estpost tabstat $vars [aw=wgt_ind] if country=="RO" & year==2022, by(arope_aux) statistics(mean) columns(statistics) nototal
esttab . using "$tables\Table6-RO.xls", main(mean) nostar unstack noobs nonote label  cells("mean(fmt(a2))") replace

*** DIFF. OF MEANS
foreach cnt in BG HR PL RO  {

putexcel set "$tables\Table6-ttest", modify sheet("`cnt'", replace) 
putexcel A2 = "age (head)"
putexcel A3 = "male"
putexcel A4 = "home ownership"
putexcel A5 = "primary education"
putexcel A6 = "secondary education"
putexcel A7 = "tertiary education "
putexcel A8 = "employed"
putexcel A9= "unemployed"
putexcel A10 = "retired"
putexcel A11 = "inactive"
putexcel A12 = "student"
putexcel A13 = "unmet medical needs"
putexcel A14 = "overcrowded house"
putexcel A15 = "number of individuals <18"
putexcel A16 = "number of individuals 18-64"
putexcel A17 = "number of individuals >64"
putexcel A18 = "female-headed hh"
putexcel A19 = "hh with unemployed"
putexcel A20 = "single-elderly hh"
putexcel A21 = "household with 3 or more children"
putexcel A22 = "hh with 5 or more members"
putexcel A23 = "hh with disability recipient"
putexcel A24 = "hh with pensioner"
putexcel A25 = "hh with social aid"
putexcel A26 = "cities"
putexcel A27 = "towns and suburbs"
putexcel A28 = "rural areas "
putexcel B1 = "`cnt' - diff."
putexcel C1 = "`cnt' - p-value"

 foreach var in $vars  {
	mean `var' [aw=wgt_ind] if country=="`cnt'" & year==2022, over(arope)
	lincom [`var']1 - [`var']0 	
	local diff_`var'= r(estimate)
	local p_`var'= r(p)
}

putexcel B2 = `diff_age', nformat(number_d2)
putexcel C2 = `p_age', nformat(#.000)
putexcel B3 = `diff_male', nformat(number_d2)
putexcel C3 = `p_male', nformat(#.000)
putexcel B4 = `diff_owner_hhead', nformat(number_d2)
putexcel C4 = `p_owner_hhead', nformat(#.000)
putexcel B5 = `diff_edu_hhead_1', nformat(number_d2)
putexcel C5 = `p_edu_hhead_1', nformat(#.000)
putexcel B6 = `diff_edu_hhead_2', nformat(number_d2)
putexcel C6 = `p_edu_hhead_2', nformat(#.000)
putexcel B7 = `diff_edu_hhead_3', nformat(number_d2)
putexcel C7 = `p_edu_hhead_3', nformat(#.000)
putexcel B8 = `diff_lfstat_hhead_1', nformat(number_d2)
putexcel C8 = `p_lfstat_hhead_1', nformat(#.000)
putexcel B9 = `diff_lfstat_hhead_2', nformat(number_d2)
putexcel C9 = `p_lfstat_hhead_2', nformat(#.000)
putexcel B10 = `diff_lfstat_hhead_3', nformat(number_d2)
putexcel C10 = `p_lfstat_hhead_3', nformat(#.000)
putexcel B11 = `diff_lfstat_hhead_4', nformat(number_d2)
putexcel C11 = `p_lfstat_hhead_4', nformat(#.000)
putexcel B12 = `diff_lfstat_hhead_5', nformat(number_d2)
putexcel C12 = `p_lfstat_hhead_5', nformat(#.000)
putexcel B13 = `diff_unmet_med_hh', nformat(number_d2)
putexcel C13 = `p_unmet_med_hh', nformat(#.000)
putexcel B14 = `diff_crowding', nformat(number_d2)
putexcel C14 = `p_crowding', nformat(#.000)
putexcel B15 = `diff_n_children_0_18', nformat(number_d2)
putexcel C15 = `p_n_children_0_18', nformat(#.000)
putexcel B16 = `diff_n_adult_18_64', nformat(number_d2)
putexcel C16 = `p_n_adult_18_64', nformat(#.000)
putexcel B17 = `diff_n_adults_65', nformat(number_d2)
putexcel C17 = `p_n_adults_65', nformat(#.000)
putexcel B18 = `diff_femaleheaded_hh', nformat(number_d2)
putexcel C18 = `p_femaleheaded_hh', nformat(#.000)
putexcel B19 = `diff_unemployed_hh', nformat(number_d2)
putexcel C19 = `p_unemployed_hh', nformat(#.000)
putexcel B20 = `diff_single_elderly_hh', nformat(number_d2)
putexcel C20 = `p_single_elderly_hh', nformat(#.000)
putexcel B21 = `diff_hh_3more_children', nformat(number_d2)
putexcel C21 = `p_hh_3more_children', nformat(#.000)
putexcel B22 = `diff_hh_5members', nformat(number_d2)
putexcel C22 = `p_hh_5members', nformat(#.000)
putexcel B23 = `diff_disabled_hh', nformat(number_d2)
putexcel C23 = `p_disabled_hh', nformat(#.000)
putexcel B24 = `diff_pensioner_hh', nformat(number_d2)
putexcel C24 = `p_pensioner_hh', nformat(#.000)
putexcel B25 = `diff_socialaid_hh', nformat(number_d2)
putexcel C25 = `p_socialaid_hh', nformat(#.000)
putexcel B26 = `diff_densely', nformat(number_d2)
putexcel C26 = `p_densely', nformat(#.000)
putexcel B27 = `diff_inter', nformat(number_d2)
putexcel C27 = `p_inter', nformat(#.000)
putexcel B28 = `diff_thinly', nformat(number_d2)
putexcel C28 = `p_thinly', nformat(#.000)	
 	
}		  

*--------------------------------------------------------
* 6) Probit and average marginal effects										
*--------------------------------------------------------				

****************************
*** TABLES A4.1 to A4.4 ***
****************************

* BG
 foreach depvar in arop lwi deprived arope  {
	
		probit `depvar'  male age ///
								owner_hhead i.edu_hhead i.lfstat_hhead ///
								unmet_med_hh crowding ///
								n_children_0_18 n_adult_18_64 n_adults_65 ///
								femaleheaded_hh unemployed_hh single_elderly_hh hh_3more_children hh_5members disabled_hh pensioner_hh socialaid_hh ///			
								inter thinly ///
								reg_BG1 reg_BG2  if code=="BG" & year==2022 [w=weight_ind], robust 
		local r2_p= e(r2_p)
		margins, dydx(*) post	
		outreg2 using "$tables\TableA4-1.xls", append ctitle(`depvar')  bdec(3) label  addstat(Pseudo R-squared, `r2_p') 
}

* HR
foreach depvar in arop  lwi deprived arope {
		probit `depvar' male age ///
								owner_hhead i.edu_hhead i.lfstat_hhead ///
								unmet_med_hh crowding ///
								n_children_0_18 n_adult_18_64 n_adults_65 ///
								femaleheaded_hh unemployed_hh single_elderly_hh hh_3more_children hh_5members disabled_hh pensioner_hh socialaid_hh ///		
								inter thinly ///
								reg_HR1 if code=="HR" & year==2022 [w=weight_ind], robust			
		local r2_p= e(r2_p)
		margins, dydx(*) post	
		outreg2 using "$tables\TableA4-2.xls", append ctitle(`depvar')  bdec(3)  label  addstat(Pseudo R-squared, `r2_p')
}

* PL
foreach depvar in arop lwi deprived arope {
		probit `depvar' male age ///
						owner_hhead i.edu_hhead i.lfstat_hhead ///
						unmet_med_hh crowding ///
						n_children_0_18 n_adult_18_64 n_adults_65 ///
						femaleheaded_hh unemployed_hh single_elderly_hh hh_3more_children hh_5members disabled_hh pensioner_hh socialaid_hh ///		
						inter thinly ///
						reg_PL1 reg_PL2 reg_PL3 reg_PL4 reg_PL5 reg_PL6 reg_PL7 if code=="PL" & year==2022 [w=weight_ind], robust		
		local r2_p= e(r2_p)
		margins, dydx(*) post	
		outreg2 using "$tables\TableA4-3.xls", append ctitle(`depvar')  bdec(3) label  addstat(Pseudo R-squared, `r2_p')
}

* RO
foreach depvar in arop lwi deprived arope {
		probit `depvar' male age ///
						owner_hhead i.edu_hhead i.lfstat_hhead ///
						unmet_med_hh crowding ///
						n_children_0_18 n_adult_18_64 n_adults_65 ///
						femaleheaded_hh unemployed_hh single_elderly_hh hh_3more_children hh_5members disabled_hh pensioner_hh ///			
						inter thinly ///
						reg_RO1 reg_RO2 reg_RO3 reg_RO4 if code=="RO" & year==2022 [w=weight_ind], robust			
		local r2_p= e(r2_p)
		margins, dydx(*) post	
		outreg2 using "$tables\TableA4-4.xls", append ctitle(`depvar')  bdec(3) label  addstat(Pseudo R-squared, `r2_p')
}


*--------------------------------------------------------
* (Some of the) Annex Tables 					
*--------------------------------------------------------

****************************
*** TABLES A4.5 to A4.8 ***
****************************

* BG
foreach depvar in arop lwi deprived arope {
	
		probit `depvar' male age ///
								owner_hhead i.edu_hhead i.lfstat_hhead ///
								unmet_med_hh crowding ///
								n_children_0_18 n_adult_18_64 n_adults_65 ///
								femaleheaded_hh unemployed_hh single_elderly_hh hh_3more_children hh_5members disabled_hh pensioner_hh socialaid_hh ///			
								inter thinly ///
								reg_BG1 reg_BG2  if code=="BG" & year==2021 [w=weight_ind], robust			
		local r2_p= e(r2_p)
		margins, dydx(*) post	
		outreg2 using "$tables\TableA4-5.xls", append ctitle(`depvar')  bdec(3) label  addstat(Pseudo R-squared, `r2_p')
}

* HR
foreach depvar in arop  lwi deprived arope {
		probit `depvar' male age ///
								owner_hhead i.edu_hhead i.lfstat_hhead ///
								unmet_med_hh crowding ///
								n_children_0_18 n_adult_18_64 n_adults_65 ///
								femaleheaded_hh unemployed_hh single_elderly_hh hh_3more_children hh_5members disabled_hh pensioner_hh socialaid_hh ///		
								inter thinly ///
								reg_HR1 if code=="HR" & year==2021 [w=weight_ind], robust			
		local r2_p= e(r2_p)
		margins, dydx(*) post	
		outreg2 using "$tables\TableA4-6.xls", append ctitle(`depvar')  bdec(3) label  addstat(Pseudo R-squared, `r2_p')
} 

* PL
foreach depvar in arop lwi deprived arope {
		probit `depvar' male age ///
						owner_hhead i.edu_hhead i.lfstat_hhead ///
						unmet_med_hh crowding ///
						n_children_0_18 n_adult_18_64 n_adults_65 ///
						femaleheaded_hh unemployed_hh single_elderly_hh hh_3more_children hh_5members disabled_hh pensioner_hh socialaid_hh ///		
						inter thinly ///
						reg_PL1 reg_PL2 reg_PL3 reg_PL4 reg_PL5 reg_PL6 reg_PL7 if code=="PL" & year==2021 [w=weight_ind], robust			
		local r2_p= e(r2_p)
		margins, dydx(*) post	
		outreg2 using "$tables\TableA4-7.xls", append ctitle(`depvar')  bdec(3) label  addstat(Pseudo R-squared, `r2_p')
}

* RO
foreach depvar in arop lwi deprived arope {
		probit `depvar' male age ///
						owner_hhead i.edu_hhead i.lfstat_hhead ///
						unmet_med_hh crowding ///
						n_children_0_18 n_adult_18_64 n_adults_65 ///
						femaleheaded_hh unemployed_hh single_elderly_hh hh_3more_children hh_5members disabled_hh pensioner_hh ///			
						inter thinly ///
						reg_RO1 reg_RO2 reg_RO3 reg_RO4 if code=="RO" & year==2021 [w=weight_ind], robust			
		local r2_p= e(r2_p)
		margins, dydx(*) post	
		outreg2 using "$tables\TableA4-8.xls", append ctitle(`depvar')  bdec(3) label  addstat(Pseudo R-squared, `r2_p')
}


*******************
*** TABLE A3.3 ***
*******************

* re-coding lwi
gen lwi_aux = 1 if lwi==1
replace lwi_aux = 2 if lwi==0

label define lwi_aux 1 "LWI" 2"non-LWI" 
label values lwi_aux lwi_aux

*** MEANS			
// Bulgaria
estpost tabstat $vars [aw=wgt_ind] if country=="BG" & year==2022, by(lwi_aux) statistics(mean) columns(statistics) nototal
esttab . using "$tables\TableA3-3-BG.xls", main(mean) nostar unstack noobs nonote label  cells("mean(fmt(a2))") replace

 // Croatia
estpost tabstat $vars [aw=wgt_ind] if country=="HR" & year==2022, by(lwi_aux) statistics(mean) columns(statistics) nototal
esttab . using "$tables\TableA3-3-HR.xls", main(mean) nostar unstack noobs nonote label  cells("mean(fmt(a2))") replace

 // Poland
estpost tabstat $vars [aw=wgt_ind] if country=="PL" & year==2022, by(lwi_aux) statistics(mean) columns(statistics) nototal
esttab . using "$tables\TableA3-3-PL.xls", main(mean) nostar unstack noobs nonote label  cells("mean(fmt(a2))") replace

 // Romania
estpost tabstat $vars [aw=wgt_ind] if country=="RO" & year==2022, by(lwi_aux) statistics(mean) columns(statistics) nototal
esttab . using "$tables\TableA3-3-RO.xls", main(mean) nostar unstack noobs nonote label  cells("mean(fmt(a2))") replace

*** DIFF. OF MEANS
foreach cnt in BG HR PL RO  {

putexcel set "$tables\TableA3-3-ttest", modify sheet("`cnt'", replace) 
putexcel A2 = "age (head)"
putexcel A3 = "male"
putexcel A4 = "home ownership"
putexcel A5 = "primary education"
putexcel A6 = "secondary education"
putexcel A7 = "tertiary education "
putexcel A8 = "employed"
putexcel A9= "unemployed"
putexcel A10 = "retired"
putexcel A11 = "inactive"
putexcel A12 = "student"
putexcel A13 = "unmet medical needs"
putexcel A14 = "overcrowded house"
putexcel A15 = "number of individuals <18"
putexcel A16 = "number of individuals 18-64"
putexcel A17 = "number of individuals >64"
putexcel A18 = "female-headed hh"
putexcel A19 = "hh with unemployed"
putexcel A20 = "single-elderly hh"
putexcel A21 = "household with 3 or more children"
putexcel A22 = "hh with 5 or more members"
putexcel A23 = "hh with disability recipient"
putexcel A24 = "hh with pensioner"
putexcel A25 = "hh with social aid"
putexcel A26 = "cities"
putexcel A27 = "towns and suburbs"
putexcel A28 = "rural areas "
putexcel B1 = "`cnt' - diff."
putexcel C1 = "`cnt' - p-value"

 foreach var in $vars  {
	mean `var' [aw=wgt_ind] if country=="`cnt'" & year==2022, over(lwi)
	lincom [`var']1 - [`var']0 	
	local diff_`var'= r(estimate)
	local p_`var'= r(p)
}

putexcel B2 = `diff_age', nformat(number_d2)
putexcel C2 = `p_age', nformat(#.000)
putexcel B3 = `diff_male', nformat(number_d2)
putexcel C3 = `p_male', nformat(#.000)
putexcel B4 = `diff_owner_hhead', nformat(number_d2)
putexcel C4 = `p_owner_hhead', nformat(#.000)
putexcel B5 = `diff_edu_hhead_1', nformat(number_d2)
putexcel C5 = `p_edu_hhead_1', nformat(#.000)
putexcel B6 = `diff_edu_hhead_2', nformat(number_d2)
putexcel C6 = `p_edu_hhead_2', nformat(#.000)
putexcel B7 = `diff_edu_hhead_3', nformat(number_d2)
putexcel C7 = `p_edu_hhead_3', nformat(#.000)
putexcel B8 = `diff_lfstat_hhead_1', nformat(number_d2)
putexcel C8 = `p_lfstat_hhead_1', nformat(#.000)
putexcel B9 = `diff_lfstat_hhead_2', nformat(number_d2)
putexcel C9 = `p_lfstat_hhead_2', nformat(#.000)
putexcel B10 = `diff_lfstat_hhead_3', nformat(number_d2)
putexcel C10 = `p_lfstat_hhead_3', nformat(#.000)
putexcel B11 = `diff_lfstat_hhead_4', nformat(number_d2)
putexcel C11 = `p_lfstat_hhead_4', nformat(#.000)
putexcel B12 = `diff_lfstat_hhead_5', nformat(number_d2)
putexcel C12 = `p_lfstat_hhead_5', nformat(#.000)
putexcel B13 = `diff_unmet_med_hh', nformat(number_d2)
putexcel C13 = `p_unmet_med_hh', nformat(#.000)
putexcel B14 = `diff_crowding', nformat(number_d2)
putexcel C14 = `p_crowding', nformat(#.000)
putexcel B15 = `diff_n_children_0_18', nformat(number_d2)
putexcel C15 = `p_n_children_0_18', nformat(#.000)
putexcel B16 = `diff_n_adult_18_64', nformat(number_d2)
putexcel C16 = `p_n_adult_18_64', nformat(#.000)
putexcel B17 = `diff_n_adults_65', nformat(number_d2)
putexcel C17 = `p_n_adults_65', nformat(#.000)
putexcel B18 = `diff_femaleheaded_hh', nformat(number_d2)
putexcel C18 = `p_femaleheaded_hh', nformat(#.000)
putexcel B19 = `diff_unemployed_hh', nformat(number_d2)
putexcel C19 = `p_unemployed_hh', nformat(#.000)
putexcel B20 = `diff_single_elderly_hh', nformat(number_d2)
putexcel C20 = `p_single_elderly_hh', nformat(#.000)
putexcel B21 = `diff_hh_3more_children', nformat(number_d2)
putexcel C21 = `p_hh_3more_children', nformat(#.000)
putexcel B22 = `diff_hh_5members', nformat(number_d2)
putexcel C22 = `p_hh_5members', nformat(#.000)
putexcel B23 = `diff_disabled_hh', nformat(number_d2)
putexcel C23 = `p_disabled_hh', nformat(#.000)
putexcel B24 = `diff_pensioner_hh', nformat(number_d2)
putexcel C24 = `p_pensioner_hh', nformat(#.000)
putexcel B25 = `diff_socialaid_hh', nformat(number_d2)
putexcel C25 = `p_socialaid_hh', nformat(#.000)
putexcel B26 = `diff_densely', nformat(number_d2)
putexcel C26 = `p_densely', nformat(#.000)
putexcel B27 = `diff_inter', nformat(number_d2)
putexcel C27 = `p_inter', nformat(#.000)
putexcel B28 = `diff_thinly', nformat(number_d2)
putexcel C28 = `p_thinly', nformat(#.000)	
 	
}		 


*******************
*** TABLE A3.4 ***
*******************

// unpacking material deprivations 
keep if year==2022
qui do "3.aux-mat_dep.do"

replace housing=0 if housing==.

* Deprivations at the Household Level
foreach var in unexpfexp holiday housing protmeal warm car furniture {
		replace `var' =  `var' * 100
}

* Deprivations at the Individual Level
foreach var in internet clothes shoes small_money leisure friends {
		gen dep_`var' = 0
		replace dep_`var' = `var'==1 | child_`var'==1
		replace dep_`var' =  dep_`var' * 100
}

putexcel set "$tables\TableA3-4", replace
putexcel A2 = "Deprivations at the Household Level"
putexcel A3 = "Capacity to face unexpected expenses"
putexcel A4 = "Capacity to afford paying for one week annual holiday"
putexcel A5 = "Capacity to being confronted with payment arrears"
putexcel A6 = "Capacity to afford a meal with meat, chicken, fish every second day"
putexcel A7 = "Ability to keep home adequately warm"
putexcel A8 = "Have access to a car/van for personal use"
putexcel A9 = "Replacing worn-out furniture"
putexcel A10 = "Deprivations at the Individual Level"
putexcel A11 = "Having internet connection"
putexcel A12 = "Replacing worn-out clothes by some new ones"
putexcel A13 = "Having two pairs of properly fitting shoes"
putexcel A14 = "Spending a small amount of money each week on him/herself"
putexcel A15 = "Having regular leisure activities"
putexcel A16 = "Getting together with friends/family at least once a month"
putexcel B1 = "Bulgaria"
putexcel C1 = "Croatia"
putexcel D1 = "Poland"
putexcel E1 = "Romania"

// Bulgaria
tabstat unexpfexp if country=="BG" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel B3 = matrix(r(StatTotal)), nformat(#.0)
tabstat holiday if country=="BG" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel B4 = matrix(r(StatTotal)), nformat(#.0)
tabstat housing if country=="BG" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel B5 = matrix(r(StatTotal)), nformat(#.0)
tabstat protmeal if country=="BG" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel B6 = matrix(r(StatTotal)), nformat(#.0)
tabstat warm if country=="BG" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel B7 = matrix(r(StatTotal)), nformat(#.0)
tabstat car if country=="BG" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel B8 = matrix(r(StatTotal)), nformat(#.0)
tabstat furniture if country=="BG" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel B9 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_internet if country=="BG" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel B11 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_clothes if country=="BG" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel B12 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_shoes if country=="BG" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel B13 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_small_money if country=="BG" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel B14 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_leisure if country=="BG" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel B15 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_friends if country=="BG" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel B16 = matrix(r(StatTotal)), nformat(#.0)

// Croatia
tabstat unexpfexp if country=="HR" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel C3 = matrix(r(StatTotal)), nformat(#.0)
tabstat holiday if country=="HR" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel C4 = matrix(r(StatTotal)), nformat(#.0)
tabstat housing if country=="HR" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel C5 = matrix(r(StatTotal)), nformat(#.0)
tabstat protmeal if country=="HR" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel C6 = matrix(r(StatTotal)), nformat(#.0)
tabstat warm if country=="HR" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel C7 = matrix(r(StatTotal)), nformat(#.0)
tabstat car if country=="HR" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel C8 = matrix(r(StatTotal)), nformat(#.0)
tabstat furniture if country=="HR" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel C9 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_internet if country=="HR" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel C11 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_clothes if country=="HR" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel C12 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_shoes if country=="HR" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel C13 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_small_money if country=="HR" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel C14 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_leisure if country=="HR" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel C15 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_friends if country=="HR" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel C16 = matrix(r(StatTotal)), nformat(#.0)

// Poland
tabstat unexpfexp if country=="PL" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel D3 = matrix(r(StatTotal)), nformat(#.0)
tabstat holiday if country=="PL" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel D4 = matrix(r(StatTotal)), nformat(#.0)
tabstat housing if country=="PL" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel D5 = matrix(r(StatTotal)), nformat(#.0)
tabstat protmeal if country=="PL" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel D6 = matrix(r(StatTotal)), nformat(#.0)
tabstat warm if country=="PL" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel D7 = matrix(r(StatTotal)), nformat(#.0)
tabstat car if country=="PL" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel D8 = matrix(r(StatTotal)), nformat(#.0)
tabstat furniture if country=="PL" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel D9 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_internet if country=="PL" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel D11 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_clothes if country=="PL" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel D12 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_shoes if country=="PL" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel D13 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_small_money if country=="PL" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel D14 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_leisure if country=="PL" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel D15 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_friends if country=="PL" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel D16 = matrix(r(StatTotal)), nformat(#.0)

// Romania
tabstat unexpfexp if country=="RO" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel E3 = matrix(r(StatTotal)), nformat(#.0)
tabstat holiday if country=="RO" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel E4 = matrix(r(StatTotal)), nformat(#.0)
tabstat housing if country=="RO" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel E5 = matrix(r(StatTotal)), nformat(#.0)
tabstat protmeal if country=="RO" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel E6 = matrix(r(StatTotal)), nformat(#.0)
tabstat warm if country=="RO" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel E7 = matrix(r(StatTotal)), nformat(#.0)
tabstat car if country=="RO" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel E8 = matrix(r(StatTotal)), nformat(#.0)
tabstat furniture if country=="RO" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel E9 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_internet if country=="RO" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel E11 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_clothes if country=="RO" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel E12 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_shoes if country=="RO" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel E13 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_small_money if country=="RO" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel E14 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_leisure if country=="RO" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel E15 = matrix(r(StatTotal)), nformat(#.0)
tabstat dep_friends if country=="RO" & mat_deprived!=. [aw=wgt_ind] , stat(mean) save 
putexcel E16 = matrix(r(StatTotal)), nformat(#.0)




