
*===============================================================================
*===============================================================================
* AROPE + --> Deprivations and profile: 4 EU countries of interest (BG-HR-RO-PL)
*===============================================================================
*===============================================================================

// data
use "$createddata/SILC_BG-HR-PL-RO_21-22.dta", clear

// keep year of interest
keep if year==2022


*--------------------------------------------------------
* 1) Materially deprived + 											//material deprivation incorporating "crowding"
*--------------------------------------------------------

qui do "$dofiles\4.aux-mat_dep_plus.do"

bys code: tabstat mat_deprived_plus rx060 [aw=wgt_ind], stats(mean) 


*--------------------------------------------------------
* 2) Analysis of AROPE +
*--------------------------------------------------------

// re-coding LWI for stats (lwi=2 -if not applicable- to 0)				
gen rx050_aux = rx050
replace rx050_aux=0 if rx050==2 	

gen rx050_2 = rx050
replace rx050_2=. if rx050==2 					 

// AROPE PLUS
gen arope_plus = 0
replace arope_plus = 100 if arop==1 | rx050==1 | mat_deprived_plus==1 | deprived_educ_hh==1 | unmet_med_hh==1

// re-expressing (*100)
foreach var in arop rx050_aux mat_deprived_plus deprived_educ_hh unmet_med_hh {
		gen `var'_1 =  `var' * 100
}
			 

****************
*** TABLE 7 ***
****************

putexcel set "$tables\Table7", replace
putexcel A2 = "Panel (A): national rates"
putexcel A3 = "AROPE +"
putexcel A4 = "Panel (B): raw headcount of each dimension"
putexcel A5 = "AROP"
putexcel A6 = "low work intensity"
putexcel A7 = "material and social deprivation +"
putexcel A8 = "education"
putexcel A9 = "health"
putexcel B1 = "Bulgaria"
putexcel C1 = "Croatia"
putexcel D1 = "Poland"
putexcel E1 = "Romania"

// Bulgaria
tabstat arope_plus if country=="BG" [aw=wgt_ind] , stat(mean) save 
putexcel B3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arop_1 if country=="BG" [aw=wgt_ind] , stat(mean) save 
putexcel B5 = matrix(r(StatTotal)), nformat(#.0)
tabstat rx050_aux_1 if country=="BG" [aw=wgt_ind] , stat(mean) save 
putexcel B6 = matrix(r(StatTotal)), nformat(#.0)
tabstat mat_deprived_plus_1 if country=="BG" [aw=wgt_ind] , stat(mean) save 
putexcel B7 = matrix(r(StatTotal)), nformat(#.0)
tabstat deprived_educ_hh_1 if country=="BG" [aw=wgt_ind] , stat(mean) save 
putexcel B8 = matrix(r(StatTotal)), nformat(#.0)
tabstat unmet_med_hh_1 if country=="BG" [aw=wgt_ind] , stat(mean) save 
putexcel B9 = matrix(r(StatTotal)), nformat(#.0)

// Croatia
tabstat arope_plus if country=="HR" [aw=wgt_ind] , stat(mean) save 
putexcel C3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arop_1 if country=="HR" [aw=wgt_ind] , stat(mean) save 
putexcel C5 = matrix(r(StatTotal)), nformat(#.0)
tabstat rx050_aux_1 if country=="HR" [aw=wgt_ind] , stat(mean) save 
putexcel C6 = matrix(r(StatTotal)), nformat(#.0)
tabstat mat_deprived_plus_1 if country=="HR" [aw=wgt_ind] , stat(mean) save 
putexcel C7 = matrix(r(StatTotal)), nformat(#.0)
tabstat deprived_educ_hh_1 if country=="HR" [aw=wgt_ind] , stat(mean) save 
putexcel C8 = matrix(r(StatTotal)), nformat(#.0)
tabstat unmet_med_hh_1 if country=="HR" [aw=wgt_ind] , stat(mean) save 
putexcel C9 = matrix(r(StatTotal)), nformat(#.0)

// Poland
tabstat arope_plus if country=="PL" [aw=wgt_ind] , stat(mean) save 
putexcel D3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arop_1 if country=="PL" [aw=wgt_ind] , stat(mean) save 
putexcel D5 = matrix(r(StatTotal)), nformat(#.0)
tabstat rx050_aux_1 if country=="PL" [aw=wgt_ind] , stat(mean) save 
putexcel D6 = matrix(r(StatTotal)), nformat(#.0)
tabstat mat_deprived_plus_1 if country=="PL" [aw=wgt_ind] , stat(mean) save 
putexcel D7 = matrix(r(StatTotal)), nformat(#.0)
tabstat deprived_educ_hh_1 if country=="PL" [aw=wgt_ind] , stat(mean) save 
putexcel D8 = matrix(r(StatTotal)), nformat(#.0)
tabstat unmet_med_hh_1 if country=="PL" [aw=wgt_ind] , stat(mean) save 
putexcel D9 = matrix(r(StatTotal)), nformat(#.0)

// Romania
tabstat arope_plus if country=="RO" [aw=wgt_ind] , stat(mean) save 
putexcel E3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arop_1 if country=="RO" [aw=wgt_ind] , stat(mean) save 
putexcel E5 = matrix(r(StatTotal)), nformat(#.0)
tabstat rx050_aux_1 if country=="RO" [aw=wgt_ind] , stat(mean) save 
putexcel E6 = matrix(r(StatTotal)), nformat(#.0)
tabstat mat_deprived_plus_1 if country=="RO" [aw=wgt_ind] , stat(mean) save 
putexcel E7 = matrix(r(StatTotal)), nformat(#.0)
tabstat deprived_educ_hh_1 if country=="RO" [aw=wgt_ind] , stat(mean) save 
putexcel E8 = matrix(r(StatTotal)), nformat(#.0)
tabstat unmet_med_hh_1 if country=="RO" [aw=wgt_ind] , stat(mean) save 
putexcel E9 = matrix(r(StatTotal)), nformat(#.0)


****************
*** TABLE 8 ***
****************
// overlapping
egen n_overlap = rowtotal(arop rx050_aux mat_deprived_plus deprived_educ_hh unmet_med_hh), missing
bys code: tab n_overlap [aw=wgt_ind] if arope_plus==100

// creating variables for different number of overlapping deprivations
forvalues i = 1(1)5 {
			gen aropeplus_`i'd = 0 if arope_plus==100
			replace aropeplus_`i'd = 100 if arope_plus==100 & n_overlap==`i'
}

putexcel set "$tables\Table8", replace
putexcel A1 = "AROPE +"
putexcel A2 = "Deprived in only 1 dimension"
putexcel A3 = "Deprived in only 2 dimensions"
putexcel A4 = "Deprived in only 3 dimensions"
putexcel A5 = "Deprived in only 4 dimensions"
putexcel A6 = "Deprived in only 5 dimensions"
putexcel B1 = "Bulgaria"
putexcel C1 = "Croatia"
putexcel D1 = "Poland"
putexcel E1 = "Romania"

// Bulgaria
tabstat aropeplus_1d if country=="BG" [aw=wgt_ind] , stat(mean) save 
putexcel B2 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_2d if country=="BG" [aw=wgt_ind] , stat(mean) save 
putexcel B3 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_3d if country=="BG" [aw=wgt_ind] , stat(mean) save 
putexcel B4 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_4d if country=="BG" [aw=wgt_ind] , stat(mean) save 
putexcel B5 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_5d if country=="BG" [aw=wgt_ind] , stat(mean) save 
putexcel B6 = matrix(r(StatTotal)), nformat(#.0)

// Croatia
tabstat aropeplus_1d if country=="HR" [aw=wgt_ind] , stat(mean) save 
putexcel C2 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_2d if country=="HR" [aw=wgt_ind] , stat(mean) save 
putexcel C3 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_3d if country=="HR" [aw=wgt_ind] , stat(mean) save 
putexcel C4 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_4d if country=="HR" [aw=wgt_ind] , stat(mean) save 
putexcel C5 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_5d if country=="HR" [aw=wgt_ind] , stat(mean) save 
putexcel C6 = matrix(r(StatTotal)), nformat(#.0)

// Poland
tabstat aropeplus_1d if country=="PL" [aw=wgt_ind] , stat(mean) save 
putexcel D2 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_2d if country=="PL" [aw=wgt_ind] , stat(mean) save 
putexcel D3 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_3d if country=="PL" [aw=wgt_ind] , stat(mean) save 
putexcel D4 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_4d if country=="PL" [aw=wgt_ind] , stat(mean) save 
putexcel D5 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_5d if country=="PL" [aw=wgt_ind] , stat(mean) save 
putexcel D6 = matrix(r(StatTotal)), nformat(#.0)

// Romania
tabstat aropeplus_1d if country=="RO" [aw=wgt_ind] , stat(mean) save 
putexcel E2 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_2d if country=="RO" [aw=wgt_ind] , stat(mean) save 
putexcel E3 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_3d if country=="RO" [aw=wgt_ind] , stat(mean) save 
putexcel E4 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_4d if country=="RO" [aw=wgt_ind] , stat(mean) save 
putexcel E5 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_5d if country=="RO" [aw=wgt_ind] , stat(mean) save 
putexcel E6 = matrix(r(StatTotal)), nformat(#.0)


****************
*** TABLE 9 ***
****************
putexcel set "$tables\Table9", replace
putexcel A1 = "vulnerable households"
putexcel A2 = "household with unemployed"
putexcel A3 = "single-elderly household"
putexcel A4 = "female-headed household"
putexcel A5 = "household with 3 or more children"
putexcel A6 = "household with 5 or more members"
putexcel A7 = "household with disability recipient"
putexcel A8 = "household with pensioner"
putexcel A9 = "household with social aid"
putexcel A10 = "national AROPE+ rate"
putexcel B1 = "Bulgaria"
putexcel C1 = "Croatia"
putexcel D1 = "Poland"
putexcel E1 = "Romania"

// Bulgaria
tabstat arope_plus if country=="BG" & year==2022 & unemployed_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel B2 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="BG" & year==2022 & single_elderly_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel B3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="BG" & year==2022 & femaleheaded_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel B4 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="BG" & year==2022 & hh_3more_children==1 [aw=wgt_ind] , stat(mean) save 
putexcel B5 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="BG" & year==2022 & hh_5members==1 [aw=wgt_ind] , stat(mean) save 
putexcel B6 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="BG" & year==2022 & disabled_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel B7 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="BG" & year==2022 & pensioner_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel B8 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="BG" & year==2022 & socialaid_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel B9 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="BG" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel B10 = matrix(r(StatTotal)), nformat(#.0)

// Croatia
tabstat arope_plus if country=="HR" & year==2022 & unemployed_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel C2 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="HR" & year==2022 & single_elderly_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel C3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="HR" & year==2022 & femaleheaded_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel C4 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="HR" & year==2022 & hh_3more_children==1 [aw=wgt_ind] , stat(mean) save 
putexcel C5 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="HR" & year==2022 & hh_5members==1 [aw=wgt_ind] , stat(mean) save 
putexcel C6 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="HR" & year==2022 & disabled_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel C7 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="HR" & year==2022 & pensioner_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel C8 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="HR" & year==2022 & socialaid_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel C9 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="HR" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel C10 = matrix(r(StatTotal)), nformat(#.0)
 
 // Poland
tabstat arope_plus if country=="PL" & year==2022 & unemployed_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel D2 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="PL" & year==2022 & single_elderly_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel D3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="PL" & year==2022 & femaleheaded_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel D4 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="PL" & year==2022 & hh_3more_children==1 [aw=wgt_ind] , stat(mean) save 
putexcel D5 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="PL" & year==2022 & hh_5members==1 [aw=wgt_ind] , stat(mean) save 
putexcel D6 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="PL" & year==2022 & disabled_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel D7 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="PL" & year==2022 & pensioner_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel D8 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="PL" & year==2022 & socialaid_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel D9 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="PL" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel D10 = matrix(r(StatTotal)), nformat(#.0)
 
  // Romania
tabstat arope_plus if country=="RO" & year==2022 & unemployed_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel E2 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="RO" & year==2022 & single_elderly_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel E3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="RO" & year==2022 & femaleheaded_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel E4 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="RO" & year==2022 & hh_3more_children==1 [aw=wgt_ind] , stat(mean) save 
putexcel E5 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="RO" & year==2022 & hh_5members==1 [aw=wgt_ind] , stat(mean) save 
putexcel E6 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="RO" & year==2022 & disabled_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel E7 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_plus if country=="RO" & year==2022 & pensioner_hh==1 [aw=wgt_ind] , stat(mean) save 
putexcel E8 = matrix(r(StatTotal)), nformat(#.0)
putexcel E9 = "-"
tabstat arope_plus if country=="RO" & year==2022 [aw=wgt_ind] , stat(mean) save 
putexcel E10 = matrix(r(StatTotal)), nformat(#.0)



*******************
*** TABLE A3.5 ***
*******************
 foreach cnt in BG HR PL RO  {

putexcel set "$tables\TableA3-5", modify sheet("`cnt'", replace)
putexcel A1 = "`cnt'"
putexcel A2 = "AROP"
putexcel A3 = "low work intensity"
putexcel A4 = "material and social deprivation +"
putexcel A5 = "education"
putexcel A6 = "health"
putexcel B1 = "AROP"
putexcel C1 = "low work intensity"
putexcel D1 = "material and social deprivation +"
putexcel E1 = "education"
putexcel F1 = "health"

putexcel B2 = "1.00"
putexcel C3 = "1.00"
putexcel D4 = "1.00"
putexcel E5 = "1.00"
putexcel F6 = "1.00"

tab arop rx050_2 [w=weight_ind] if country=="`cnt'", V chi2
local cramer1 = r(CramersV)
putexcel C2 = `cramer1', nformat(number_d2)

tab arop mat_deprived_plus [w=weight_ind]  if country=="`cnt'", V chi2
local cramer2 = r(CramersV)
putexcel D2 = `cramer2', nformat(number_d2)

tab arop deprived_educ_hh [w=weight_ind]  if country=="`cnt'", V chi2
local cramer3 = r(CramersV)
putexcel E2 = `cramer3', nformat(number_d2)

tab arop unmet_med_hh [w=weight_ind]  if country=="`cnt'", V chi2
local cramer4 = r(CramersV)
putexcel F2 = `cramer4', nformat(number_d2)

tab rx050_2 mat_deprived_plus [w=weight_ind]  if country=="`cnt'", V chi2
local cramer5 = r(CramersV)
putexcel D3 = `cramer5', nformat(number_d2)

tab rx050_2 deprived_educ_hh [w=weight_ind]  if country=="`cnt'", V chi2
local cramer6 = r(CramersV)
putexcel E3 = `cramer6', nformat(number_d2)

tab rx050_2 unmet_med_hh [w=weight_ind]  if country=="`cnt'", V chi2
local cramer7 = r(CramersV)
putexcel F3 = `cramer7', nformat(number_d2)

tab mat_deprived_plus deprived_educ_hh [w=weight_ind]  if country=="`cnt'", V chi2
local cramer8 = r(CramersV)
putexcel E4 = `cramer8', nformat(number_d2)

tab mat_deprived_plus unmet_med_hh [w=weight_ind]  if country=="`cnt'", V chi2
local cramer9 = r(CramersV)
putexcel F4 = `cramer9', nformat(number_d2)

tab deprived_educ_hh unmet_med_hh [w=weight_ind]  if country=="`cnt'", V chi2
local cramer10 = r(CramersV)
putexcel F5 = `cramer10', nformat(number_d2)
}


