
*===============================================================================
*===============================================================================
* AROPE Analysis in Bulgaria, with a focus on the Roma population
*===============================================================================
*===============================================================================

*--------------------------------------------------------
* 0) Transforming ethnicity data (R_Ethnos)										
*--------------------------------------------------------

import delimited "$rawbulg/UDB_cBG21R_Ethnos.csv", asdouble clear
save "$createddata/UDB_cBG21R_Ethnos.dta", replace

*--------------------------------------------------------
* 1) AROPE in the Roma population 												
*--------------------------------------------------------

// data
use "$createddata/SILC_BG-HR-PL-RO_21-22", clear

// Bulgaria, 2021
keep if code=="BG"
keep if year==2021

// check
duplicates report rb030
duplicates tag rb030, gen(dup_rb030)
drop if dup_rb030==1

// adding ethnicity from Bulgaria National SILC
qui merge 1:1 rb030 using "$createddata\UDB_cBG21R_Ethnos", keepusing(e1)
drop _merge 

// ethnicity
tab e1  [aw=wgt_ind] 
 /* 
1. Bulgarian
2. Turkish
3. Roma
4. Other
5. Not stated
6. Not answered
 */
 
// Roma
gen roma = 0
replace roma = 1 if e1==3
label var roma "Roma"


*****************
*** TABLE 10 ***
*****************

putexcel set "$tables\Table10", replace
putexcel A1 = "AROPE"
putexcel A2 = "Deprived in only 1 dimension"
putexcel A3 = "low work intensity"
putexcel A4 = "severe material and social deprivation"
putexcel A5 = "at risk of poverty"
putexcel A6 = "Deprived in only 2 dimensions"
putexcel A7 = "several material and social deprivation + low work intensity"
putexcel A8 = "at risk of poverty + low work intensity"
putexcel A9 = "at risk of poverty + several material and social deprivation"
putexcel A10 = "Deprived in 3 dimensions"
putexcel A11 = "at risk of poverty + low work intensity + several material and social deprivation"
putexcel A12 = "national AROPE rate"
putexcel B1 = "Bulgaria"
putexcel C1 = "Roma"

// Bulgaria
tabstat dim1_lwi [aw=wgt_ind] , stat(mean) save 
putexcel B3 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim1_md [aw=wgt_ind] , stat(mean) save 
putexcel B4 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim1_arop [aw=wgt_ind] , stat(mean) save 
putexcel B5 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_md_lwi [aw=wgt_ind] , stat(mean) save 
putexcel B7 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_arp_lwi [aw=wgt_ind] , stat(mean) save 
putexcel B8 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_arp_md [aw=wgt_ind] , stat(mean) save 
putexcel B9 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim3_all3 [aw=wgt_ind] , stat(mean) save 
putexcel B11 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat [aw=wgt_ind] , stat(mean) save 
putexcel B12 = matrix(r(StatTotal)), nformat(#.0)

// Bulgaria
tabstat dim1_lwi if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C3 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim1_md if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C4 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim1_arop if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C5 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_md_lwi if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C7 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_arp_lwi if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C8 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim2_arp_md if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C9 = matrix(r(StatTotal)), nformat(#.0)
tabstat dim3_all3 if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C11 = matrix(r(StatTotal)), nformat(#.0)
tabstat arope_nat if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C12 = matrix(r(StatTotal)), nformat(#.0)


*--------------------------------------------------------
* 2)  AROPE + in the Roma population
*--------------------------------------------------------

// construct materially deprived dimensions
qui run "$dofiles\4.aux-mat_dep_plus.do"

// re-coding LWI for stats (lwi=2 -if not applicable- to 0)				
gen rx050_aux = rx050
replace rx050_aux=0 if rx050==2 	

gen rx050_2 = rx050
replace rx050_2=. if rx050==2 					 

// AROPE PLUS
gen arope_plus = 0
replace arope_plus = 100 if arop==1 | rx050==1 | mat_deprived_plus==1 | deprived_educ_hh==1 | unmet_med_hh==1

// re-expressing (*100)
foreach var in arop rx050_aux mat_deprived_plus deprived_educ_hh unmet_med_hh {
		gen `var'_1 =  `var' * 100
}
		

*****************
*** TABLE 11 ***
*****************
putexcel set "$tables\Table11", replace
putexcel A2 = "Panel (A): national rates"
putexcel A3 = "AROPE +"
putexcel A4 = "Panel (B): raw headcount of each dimension"
putexcel A5 = "AROP"
putexcel A6 = "low work intensity"
putexcel A7 = "material and social deprivation +"
putexcel A8 = "education"
putexcel A9 = "health"
putexcel B1 = "Bulgaria"
putexcel C1 = "Roma"

// Bulgaria
tabstat arope_plus [aw=wgt_ind] , stat(mean) save 
putexcel B3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arop_1 [aw=wgt_ind] , stat(mean) save 
putexcel B5 = matrix(r(StatTotal)), nformat(#.0)
tabstat rx050_aux_1 [aw=wgt_ind] , stat(mean) save 
putexcel B6 = matrix(r(StatTotal)), nformat(#.0)
tabstat mat_deprived_plus_1 [aw=wgt_ind] , stat(mean) save 
putexcel B7 = matrix(r(StatTotal)), nformat(#.0)
tabstat deprived_educ_hh_1 [aw=wgt_ind] , stat(mean) save 
putexcel B8 = matrix(r(StatTotal)), nformat(#.0)
tabstat unmet_med_hh_1 [aw=wgt_ind] , stat(mean) save 
putexcel B9 = matrix(r(StatTotal)), nformat(#.0)

// Roma
tabstat arope_plus if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C3 = matrix(r(StatTotal)), nformat(#.0)
tabstat arop_1  if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C5 = matrix(r(StatTotal)), nformat(#.0)
tabstat rx050_aux_1  if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C6 = matrix(r(StatTotal)), nformat(#.0)
tabstat mat_deprived_plus_1  if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C7 = matrix(r(StatTotal)), nformat(#.0)
tabstat deprived_educ_hh_1  if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C8 = matrix(r(StatTotal)), nformat(#.0)
tabstat unmet_med_hh_1  if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C9 = matrix(r(StatTotal)), nformat(#.0)


*****************
*** TABLE 12 ***
*****************

// overlapping
egen n_overlap = rowtotal(arop rx050_aux mat_deprived_plus deprived_educ_hh unmet_med_hh), missing
bys code: tab n_overlap [aw=wgt_ind] if arope_plus==100

// creating variables for different number of overlapping deprivations
forvalues i = 1(1)5 {
			gen aropeplus_`i'd = 0 if arope_plus==100
			replace aropeplus_`i'd = 100 if arope_plus==100 & n_overlap==`i'
}

putexcel set "$tables\Table12", replace
putexcel A1 = "AROPE +"
putexcel A2 = "Deprived in only 1 dimension"
putexcel A3 = "Deprived in only 2 dimensions"
putexcel A4 = "Deprived in only 3 dimensions"
putexcel A5 = "Deprived in only 4 dimensions"
putexcel A6 = "Deprived in only 5 dimensions"
putexcel B1 = "Bulgaria"
putexcel C1 = "Roma"

// Bulgaria
tabstat aropeplus_1d [aw=wgt_ind] , stat(mean) save 
putexcel B2 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_2d [aw=wgt_ind] , stat(mean) save 
putexcel B3 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_3d [aw=wgt_ind] , stat(mean) save 
putexcel B4 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_4d [aw=wgt_ind] , stat(mean) save 
putexcel B5 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_5d [aw=wgt_ind] , stat(mean) save 
putexcel B6 = matrix(r(StatTotal)), nformat(#.0)

// Roma
tabstat aropeplus_1d if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C2 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_2d if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C3 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_3d if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C4 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_4d  if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C5 = matrix(r(StatTotal)), nformat(#.0)
tabstat aropeplus_5d if roma==1 [aw=wgt_ind] , stat(mean) save 
putexcel C6 = matrix(r(StatTotal)), nformat(#.0)



*--------------------------------------------------------
* (Some of the) Annex Tables 					
*--------------------------------------------------------

*******************
*** TABLE A3.6 ***
*******************

version 15

// to report 1st column Roma
gen roma_aux = 1 if roma==1
replace roma_aux=2 if roma==0

label define roma_aux 1 "Roma" 2"non-Roma" 
label values roma_aux roma_aux

// variables of interest
global vars age male ///
					owner_hhead edu_hhead_1 edu_hhead_2 edu_hhead_3 lfstat_hhead_1 lfstat_hhead_2 lfstat_hhead_3 lfstat_hhead_4 lfstat_hhead_5 ///
					unmet_med_hh crowding ///
					n_children_0_18 n_adult_18_64 n_adults_65 ///
					femaleheaded_hh unemployed_hh single_elderly_hh hh_3more_children hh_5members disabled_hh pensioner_hh socialaid_hh ///
					densely inter thinly

estpost tabstat $vars [aw=wgt_ind], by(roma_aux) statistics(mean) columns(statistics) nototal
esttab . using "$tables\TableA3-6.xls", main(mean) nostar unstack noobs nonote label  cells("mean(fmt(a2))") replace

putexcel set "$tables\TableA3-6-ttest", replace
putexcel A2 = "age (head)"
putexcel A3 = "male"
putexcel A4 = "home ownership"
putexcel A5 = "primary education"
putexcel A6 = "secondary education"
putexcel A7 = "tertiary education "
putexcel A8 = "employed"
putexcel A9= "unemployed"
putexcel A10 = "retired"
putexcel A11 = "inactive"
putexcel A12 = "student"
putexcel A13 = "unmet medical needs"
putexcel A14 = "overcrowded house"
putexcel A15 = "number of individuals <18"
putexcel A16 = "number of individuals 18-64"
putexcel A17 = "number of individuals >64"
putexcel A18 = "female-headed hh"
putexcel A19 = "hh with unemployed"
putexcel A20 = "single-elderly hh"
putexcel A21 = "household with 3 or more children"
putexcel A22 = "hh with 5 or more members"
putexcel A23 = "hh with disability recipient"
putexcel A24 = "hh with pensioner"
putexcel A25 = "hh with social aid"
putexcel A26 = "cities"
putexcel A27 = "towns and suburbs"
putexcel A28 = "rural areas "
putexcel B1 = "diff."
putexcel C1 = "p-value"

 foreach var in $vars  {
	mean `var' [aw=wgt_ind], over(roma)
	lincom [`var']1 - [`var']0 	
	local diff_`var'= r(estimate)
	local p_`var'= r(p)
}

putexcel B2 = `diff_age', nformat(number_d2)
putexcel C2 = `p_age', nformat(#.000)
putexcel B3 = `diff_male', nformat(number_d2)
putexcel C3 = `p_male', nformat(#.000)
putexcel B4 = `diff_owner_hhead', nformat(number_d2)
putexcel C4 = `p_owner_hhead', nformat(#.000)
putexcel B5 = `diff_edu_hhead_1', nformat(number_d2)
putexcel C5 = `p_edu_hhead_1', nformat(#.000)
putexcel B6 = `diff_edu_hhead_2', nformat(number_d2)
putexcel C6 = `p_edu_hhead_2', nformat(#.000)
putexcel B7 = `diff_edu_hhead_3', nformat(number_d2)
putexcel C7 = `p_edu_hhead_3', nformat(#.000)
putexcel B8 = `diff_lfstat_hhead_1', nformat(number_d2)
putexcel C8 = `p_lfstat_hhead_1', nformat(#.000)
putexcel B9 = `diff_lfstat_hhead_2', nformat(number_d2)
putexcel C9 = `p_lfstat_hhead_2', nformat(#.000)
putexcel B10 = `diff_lfstat_hhead_3', nformat(number_d2)
putexcel C10 = `p_lfstat_hhead_3', nformat(#.000)
putexcel B11 = `diff_lfstat_hhead_4', nformat(number_d2)
putexcel C11 = `p_lfstat_hhead_4', nformat(#.000)
putexcel B12 = `diff_lfstat_hhead_5', nformat(number_d2)
putexcel C12 = `p_lfstat_hhead_5', nformat(#.000)
putexcel B13 = `diff_unmet_med_hh', nformat(number_d2)
putexcel C13 = `p_unmet_med_hh', nformat(#.000)
putexcel B14 = `diff_crowding', nformat(number_d2)
putexcel C14 = `p_crowding', nformat(#.000)
putexcel B15 = `diff_n_children_0_18', nformat(number_d2)
putexcel C15 = `p_n_children_0_18', nformat(#.000)
putexcel B16 = `diff_n_adult_18_64', nformat(number_d2)
putexcel C16 = `p_n_adult_18_64', nformat(#.000)
putexcel B17 = `diff_n_adults_65', nformat(number_d2)
putexcel C17 = `p_n_adults_65', nformat(#.000)
putexcel B18 = `diff_femaleheaded_hh', nformat(number_d2)
putexcel C18 = `p_femaleheaded_hh', nformat(#.000)
putexcel B19 = `diff_unemployed_hh', nformat(number_d2)
putexcel C19 = `p_unemployed_hh', nformat(#.000)
putexcel B20 = `diff_single_elderly_hh', nformat(number_d2)
putexcel C20 = `p_single_elderly_hh', nformat(#.000)
putexcel B21 = `diff_hh_3more_children', nformat(number_d2)
putexcel C21 = `p_hh_3more_children', nformat(#.000)
putexcel B22 = `diff_hh_5members', nformat(number_d2)
putexcel C22 = `p_hh_5members', nformat(#.000)
putexcel B23 = `diff_disabled_hh', nformat(number_d2)
putexcel C23 = `p_disabled_hh', nformat(#.000)
putexcel B24 = `diff_pensioner_hh', nformat(number_d2)
putexcel C24 = `p_pensioner_hh', nformat(#.000)
putexcel B25 = `diff_socialaid_hh', nformat(number_d2)
putexcel C25 = `p_socialaid_hh', nformat(#.000)
putexcel B26 = `diff_densely', nformat(number_d2)
putexcel C26 = `p_densely', nformat(#.000)
putexcel B27 = `diff_inter', nformat(number_d2)
putexcel C27 = `p_inter', nformat(#.000)
putexcel B28 = `diff_thinly', nformat(number_d2)
putexcel C28 = `p_thinly', nformat(#.000)	
		  

*******************
*** TABLE A4.9 ***
*******************

// regression analysis
foreach depvar in arop lwi deprived arope {
	
		probit `depvar' male age ///
								owner_hhead i.edu_hhead i.lfstat_hhead ///
								unmet_med_hh crowding ///
								n_children_0_18 n_adult_18_64 n_adults_65 ///
								roma /// 
								femaleheaded_hh unemployed_hh single_elderly_hh hh_3more_children hh_5members disabled_hh pensioner_hh socialaid_hh ///			
								inter thinly ///
								reg_BG1 reg_BG2  [w=weight_ind], robust			
		local r2_p= e(r2_p)
		margins, dydx(*) post	
		outreg2 using "$tables\TableA4-9.xls", append ctitle(`depvar')  bdec(3) label addstat(Pseudo R-squared, `r2_p')
}



